import React, { FC } from "react";
import "./button.scss";
import cs from "classnames";
import "../global.scss";

export type ButtonType = "button" | "reset" | "submit";
export interface ButtonProps {
  type?: ButtonType;
  primary?: boolean;
  label: string;
  disabled?: boolean;
  isLoading?: boolean;
  special?: boolean;
  mobile?: boolean;
  fullwidth?: boolean;
  onClick?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
}

const Button: FC<ButtonProps> = ({
  primary = true,
  onClick,
  label,
  type,
  disabled,
  isLoading,
  special,
  mobile,
  fullwidth,
}: ButtonProps) => {
  return (
    <button
      type={type}
      className={cs("storybook-button", {
        "storybook-button-disabled": disabled,
        "storybook-button--secondary": !primary,
        "storybook-bytton--special": special,
        "storybook-bytton--fullwidth": fullwidth,
      })}
      onClick={onClick}
      disabled={disabled}
    >
      <span
        className={cs("button-container", {
          "buton-container--loading": isLoading,
          "buton-container--mobile": mobile,
        })}
      >
        {label}
        {isLoading && <div className="loading"></div>}
      </span>
    </button>
  );
};

export default Button;
