import PhysicIcon from '@src/assets/navbar-icons/physic';
import PhysicColoredIcon from '@src/assets/navbar-icons/physic-colored';
import Suitcase from '@src/assets/navbar-icons/suitcase';
import SuitcaseColored from '@src/assets/navbar-icons/suitcase-colored';
import IconUserAzul from '@src/assets/new-navbar-icons/iconUserAzul';
import IconUserBlanco from '@src/assets/new-navbar-icons/iconUserBlanco';
import cs from 'classnames';
import React, {useEffect, useState} from 'react';

type Props = {
    handleNavigationLink: (link: string) => void;
    handleOpened: (opened: number) => void;
    popover: number;
    openedBar: boolean;
};

export default function LoginNavbarComponent({
    handleNavigationLink,
    handleOpened,
    popover,
    openedBar,
}: Props): JSX.Element {
    const [isSelected, setSelected] = useState(0);
    const [changeImage, setChangeImage] = useState(0);
    const [navigatorLanguaje, setNavigatorLanguaje] = useState<any>();

    const handleOpenInfo = (number: number) => {
        if (isSelected === number) {
            setSelected(0);
            handleOpened(0);
        } else {
            setSelected(number);
            handleOpened(3);
        }
    };

    useEffect(() => {
        if (popover === 1 || popover === 2) {
            setSelected(0);
            handleOpened(0);
        }
        if (navigator) {
            setNavigatorLanguaje(navigator.language);
        }
    }, [popover]);

    return (
        <div
            className={'nav-section'}
            onClick={() => {
                handleOpenInfo(3);
            }}
        >
            <span
                className={cs('nav-link', {
                    'nav-text-selected': openedBar,
                })}
            >
                {openedBar ? <IconUserAzul /> : <IconUserBlanco />}
                Login
            </span>
            {isSelected === 3 && (
                <div className={'nav-popover-login'}>
                    <div className={'column-container-login'}>
                        <div
                            className={'link-container'}
                            onMouseOver={() => setChangeImage(1)}
                            onMouseLeave={() => setChangeImage(0)}
                            onClick={() => {
                                handleNavigationLink('/login');
                            }}
                        >
                            {changeImage !== 1 && (
                                <div className={'image-login'}>
                                    <PhysicIcon width={25} height={25} />
                                </div>
                            )}
                            {changeImage === 1 && (
                                <div className={'image-login'}>
                                    <PhysicColoredIcon width={25} height={25} />
                                </div>
                            )}
                            <div className={'text'}>
                                {navigatorLanguaje &&
                                navigatorLanguaje.includes('es')
                                    ? 'Mis Entradas'
                                    : 'My tickets'}
                            </div>
                        </div>
                        <div
                            className={'link-container'}
                            onMouseOver={() => setChangeImage(2)}
                            onMouseLeave={() => setChangeImage(0)}
                            onClick={() => {
                                handleNavigationLink('/login?producer');
                            }}
                        >
                            {changeImage !== 2 && (
                                <div className={'image-login'}>
                                    <Suitcase />
                                </div>
                            )}
                            {changeImage === 2 && (
                                <div className={'image-login'}>
                                    <SuitcaseColored />
                                </div>
                            )}
                            <div className={'text'}>
                                {navigatorLanguaje &&
                                navigatorLanguaje.includes('es')
                                    ? 'Productor'
                                    : 'Producer'}
                            </div>
                        </div>
                    </div>
                </div>
            )}
        </div>
    );
}
