import './index.scss';
import '../global.scss';

import LogoAzul from '@src/images/logoAzul';
import LogoBlanco from '@src/images/logoBlanco';
import cs from 'classnames';
import React, {useEffect, useState} from 'react';

import Announce from '../Announce';
import Button from '../Button';
import LoginNavbarComponent from './components/login';

export type NavProps = {
    showAnnounce?: boolean;
    announceText?: string;
    resaltedText?: string;
    changeLanguage?: boolean;
    handleNavNavigation: (location: string) => void;
    handleChangeLanguage: (change: boolean) => void;
    eventView?: boolean;
    isFixed?: boolean;
    homeView?: boolean;
};

export default function EventNavbar({
    handleNavNavigation,
    showAnnounce,
    announceText,
    resaltedText,
    changeLanguage,
    handleChangeLanguage,
    eventView,
    isFixed,
    homeView,
}: NavProps): JSX.Element {
    const [openedBar, setOpenedBar] = useState(false);
    const [popover, setPopover] = useState(0);
    const [strapi, setStrapi] = useState<any>();
    const [navigatorLanguaje, setNavigatorLanguaje] = useState<any>();
    const [url, setUrl] = useState('');

    useEffect(() => {
        setUrl(getDomain());
        if (navigator) {
            setNavigatorLanguaje(navigator.language);
        }
    }, []);

    function getDomain(): string {
        if (
            typeof window !== 'undefined' &&
            window.location.hostname.includes('staging')
        ) {
            return 'https://staging.ecopass.app/';
        }
        const domain =
            typeof window !== 'undefined'
                ? window.location.hostname
                : 'localhost';
        return `${
            typeof window !== 'undefined' ? window.location.protocol : 'http:'
        }//${domain === 'localhost' ? 'www.ecopass.cl' : domain}`;
    }

    return (
        <div
            className={cs('container-nav-ann', {
                'container-nav-ann-static': isFixed,
            })}
        >
            {showAnnounce && (
                <Announce text={announceText} resalted={resaltedText} />
            )}
            <div className={cs('nav-container')}>
                <div className={'nav-content'}>
                    <a className={'nav-logo'} href={url}>
                        {openedBar ? <LogoAzul /> : <LogoBlanco />}
                    </a>
                    <nav
                        className={cs('navbar', {
                            'event-navbar': eventView,
                        })}
                    >
                        <div className={'nav-section'}>
                            {homeView && strapi && (
                                <div className={'nav-section'}>
                                    <a
                                        className="navbar-button"
                                        onClick={() => {
                                            handleNavNavigation(
                                                '/login?producer',
                                            );
                                        }}
                                    >
                                        <Button
                                            label={
                                                navigatorLanguaje &&
                                                navigatorLanguaje.includes('es')
                                                    ? 'Crear evento'
                                                    : 'Create event'
                                            }
                                            primary={!openedBar}
                                        ></Button>
                                    </a>
                                </div>
                            )}
                            <LoginNavbarComponent
                                handleNavigationLink={(link) => {
                                    handleNavNavigation(link);
                                }}
                                popover={popover}
                                handleOpened={(opened) => {
                                    setPopover(opened);
                                }}
                                openedBar={openedBar}
                            />
                            {changeLanguage && (
                                <div
                                    className={'language-container'}
                                    onClick={() => handleChangeLanguage(true)}
                                >
                                    Idioma
                                </div>
                            )}
                        </div>
                    </nav>
                </div>
            </div>
        </div>
    );
}
